@@ -3,12 +3,7 @@ use strict;
 use warnings;
 use utf8;
 require LWP::UserAgent;
-use HTML::Entities;
-use Web::Scraper;
-use URI;
-
 my $last_pos;
-my $vimonline_search_url = "http://www.vim.org/scripts/script_search_results.php";
 
 sub parse_columns {
     my $c       = ${ $_[0] };
@@ -17,8 +12,7 @@ sub parse_columns {
         my $column_html = $1;
         while ( $column_html =~ m{<th.*?>(.*?)</th>}g ) {
             my $name = $1;
-            $name = decode_entities( $name );
-            utf8::encode $name;
+            $name =~ s{</?.+?>}{}g;
             push @$columns,lc $name;
         }
     }
@@ -46,9 +40,6 @@ ROW_END:
         while ( $tr =~ m{<td.*?>(.*?)</td>}gsi ) {
             my $td = $1;
             if( my ( $link, $text ) = ( $td =~ m{<a href="(.+?)">(.+?)</a>}i )  ) {
-                $text =~ s{&nbsp;}{ }g; # windows don't have 0xA0.
-                $text = decode_entities( $text );
-                utf8::encode $text;
                 ($script_id) = ( $link =~ /script_id=(\d+)/ );
                 $cols->{ $column_names->[ $col_index ] } = { text => $text, link => $link };
             }
@@ -82,7 +73,6 @@ sub fetch {
     my $content;
     unless( $content ) {
         my $ua = LWP::UserAgent->new;
-        $ua->env_proxy;
         my $response = $ua->get( $uri );
         # XXX: catch exception 
 
@@ -110,21 +100,16 @@ sub build_search_uri {
     my %args = (
         keywords    => '',
         order_by    => 'rating',
+        #show_me     => 1000,
+        #result_ptr  => 0,
         %param ,
     );
 
-    my $uri = URI->new($vimonline_search_url);
+    my $uri = URI->new("http://www.vim.org/scripts/script_search_results.php");
     $uri->query_form( %args ); 
     return $uri;
 }
 
-sub all_vim_plugins {
-    my $class = shift;
-    my $scraper = scraper {
-        process '/html/body/table[2]/tr/td[3]/table/tr/td/table/tr/td[2]/b[3]', 'total' => 'TEXT';
-    };
-    return $scraper->scrape(URI->new($vimonline_search_url))->{total};
-}
 
 
 1;
